"""
SALMA CLI

About:
------
The SALMA command line interface (CLI) is a tool designed to utilize the SALMA function for processing Arabic sentences. This CLI allows users to input an Arabic sentence and receive a structured response that includes the processing result of the SALMA function.

Usage:
------
Below is the usage information that can be generated by running the command with the --help option.

.. code-block:: none

    sina_salma --text=TEXT
    sina_salma --file=INPUT_FILE

Options:
--------
.. code-block:: none

  --text
        The Arabic sentence to be processed by the SALMA function.
  --file 
        The text file to be processed by the SALMA function.

Examples:
---------
.. code-block:: none

    sina_salma --text "your Arabic sentence here"
    sina_salma --file "path/to/your/file.txt"

Note:
-----

.. code-block:: none

    - The input sentence should be provided in Arabic.
    - It is recommended that the length of the input sentence does not exceed 500 characters to ensure optimal performance and accurate results.

"""

import argparse
import json
from nlptools.salma.views import SALMA
from nlptools.utils.readfile import read_file

def main():
    parser = argparse.ArgumentParser(description='Arabic text stripping tool using SinaTools')
    
    parser.add_argument('--text', type=str, help='Input sentence to process')
    parser.add_argument('--file', type=str, help='File containing the Arabic sentence to process')

    args = parser.parse_args()

    if args.text is None and args.file is None:
        print("Either --text or --file argument must be provided.")
        return
    
    text_content = args.text if args.text else " ".join(read_file(args.file))
    result = SALMA(text_content)
    print(json.dumps(result, ensure_ascii=False, indent=4))

if __name__ == "__main__":
    main()

#sina_salma --text "your Arabic sentence here"
#sina_salma --file "path/to/your/file.txt"